@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 58 2011-12-21 01:51:26Z yablacky $
+# $Id: smscon_service.py 74 2011-12-23 01:10:39Z yablacky $
 ##############################################################
 
 # standard modules
@@ -29,7 +29,7 @@ from email.MIMEMultipart import MIMEMultipart
 
 import smsconlib as smscon
 from smsconlib import InstPath, LogPath, PhotoName, MapName, AudioFile, DaemonFile 
-from smsconlib import IF, IsHostReachable, IsInternetReachable, IsFileReadable, DeleteFile, pidof, SendSMSviaGSMmodem
+from smsconlib import IF, IsHostReachable, IsInternetReachable, IsSamePhoneNumber, IsFileReadable, DeleteFile, shellArg, pidof, SendSMSviaGSMmodem
 
 LOGGER = smscon.LOGGER = smscon.StartLogging('DAEMON', withConsole = False)
 
@@ -106,7 +106,7 @@ def RevealThat(Subject, Text, SendMethod = None, Attachment = None, Attachhint =
             Revealed.append(smscnf.SENDERNUMBER)
 
         # Send to the master if that is different 
-        if smscnf.MASTERNUMBER != smscnf.SENDERNUMBER:
+        if not IsSamePhoneNumber(smscnf.MASTERNUMBER, smscnf.SENDERNUMBER):
             if Revealed: 
                 TextLines.append('\nBC:%s' % smscnf.SENDERNUMBER)   # "blind copy" information
             if SMSsend(smscnf.MASTERNUMBER, TextLines, 'send SMS message (subject=%s) to {RECIPIENTNUMBER}' % Subject):
@@ -506,7 +506,7 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
         SaveSenderPhoneNumber(SenderPhoneNumber)
         CommandOrigin = CommandOrigin or "SMS"
         ExtraInfo = 'from %s (%s) %s' % (SenderPhoneNumber,
-                                        IF(SenderPhoneNumber == smscnf.MASTERNUMBER, 'the master', 'NOT master'),
+                                        IF(IsSamePhoneNumber(SenderPhoneNumber, smscnf.MASTERNUMBER), 'the master', 'NOT master'),
                                         ExtraInfo)
     else:
         CommandOrigin = str(CommandOrigin)
@@ -633,7 +633,22 @@ def ProcessCommand(Command, SenderPhoneNumber=None, CommandOrigin=None, ExtraInf
 def PerformAlarm():
     """
     Make phone play sound file for alarm.
-    """ 
+    """
+
+    AudioFilename = os.path.join(InstPath, AudioFile)
+    if not IsFileReadable(AudioFilename):
+        LOGGER.error('(ALARM) Audiofile does not exist or is not readable: %s' % AudioFilename)
+        RevealThat('alarm', 'Audiofile does not exist or is not readable.')        
+        return
+
+    PrePlayCommand = []
+    PostPlayCommand = []
+    
+    # Before dealing with phone profiles and playing our alarm sound,
+    # wait a little until the sounds are done that the phone will
+    # play on receiving the sms message (the COM_ALARM message).... 
+    PrePlayCommand.append("sleep 10")
+
     # get current active phone profile
     Output = os.popen('dbus-send --print-reply \
                       --session --dest=com.nokia.profiled \
@@ -644,56 +659,49 @@ def PerformAlarm():
 
     try:
         CurrentProfile = E.findall(Output)[0]
-    except:
-        LOGGER.error('(ALARM) Could not get current phone profile.')
-        return
+    except Exception, e:
+        CurrentProfile = 'general'
+        LOGGER.warning('(ALARM) Could not get current phone profile: %s' % e)
 
+    SetPhoneProfileCommand = 'dbus-send --type=method_call' \
+                              ' --dest=com.nokia.profiled' \
+                              ' /com/nokia/profiled' \
+                              ' com.nokia.profiled.set_profile string:%s'
+
+    LOGGER.info('(ALARM) current profile is "%s".' % CurrentProfile)
     if CurrentProfile != 'general':
-        # set "General" profile
-        os.system('dbus-send --type=method_call \
-                  --dest=com.nokia.profiled \
-                  /com/nokia/profiled \
-                  com.nokia.profiled.set_profile string:"general"')
-        LOGGER.info('(ALARM) Set phone profile to "General".')
-    else:
-        LOGGER.info('(ALARM) current profile is "%s".' % CurrentProfile)
+        LOGGER.info('(ALARM) Set phone profile temporarily to "General" for alarm.')
+        PrePlayCommand.append(SetPhoneProfileCommand % shellArg('general'))
+        RestoreProfileCommand.append(SetPhoneProfileCommand % shellArg(CurrentProfile))
 
     # set volume to maximum
     Volume = 100
-    os.system('dbus-send --type=method_call \
-               --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer \
-               /com/nokia/mafw/renderer/gstrenderer \
-               com.nokia.mafw.extension.set_extension_property \
-               string:volume variant:uint32:%s' % Volume)
+    PrePlayCommand.append('dbus-send --type=method_call' \
+               ' --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer' \
+               ' /com/nokia/mafw/renderer/gstrenderer' \
+               ' com.nokia.mafw.extension.set_extension_property' \
+               ' string:volume variant:uint32:%s' % shellArg(Volume))
     
     # play audio
-    #gobject.timeout_add( PlayAudio(AudioFile) )
-    PlayAudio(AudioFile, Wait=True)
+    ok = PlayAudio(AudioFilename,
+                PrePlayCommand  = ';'.join(PrePlayCommand),
+                PostPlayCommand = ';'.join(PostPlayCommand))
+    RevealThat('alarm', IF(ok, 'Alarm sound activated.', 'Alarm sound activation failed.'))        
 
-    # set previous profile
-    os.system('dbus-send --type=method_call \
-              --dest=com.nokia.profiled \
-              /com/nokia/profiled \
-              com.nokia.profiled.set_profile string:"%s"' % CurrentProfile)
-
-    RevealThat('alarm', 'Alarm sound activated.')        
-
-def PlayAudio(File, Wait=False):
+def PlayAudio(AudioFilename, PrePlayCommand = None, PostPlayCommand = None):
     """
     Play audio file in background.
     @return bool Success indicator.
     """ 
+    PrePlayCommand  = PrePlayCommand  or 'true'
+    PostPlayCommand = PostPlayCommand or 'true'
     try:
-        os.system( '/usr/bin/aplay -q "%s" &' % os.path.join(InstPath, File) )
-    except:
-        LOGGER.error('(ALARM) Failed to play audio file.')
+        os.system( '(%s; /usr/bin/aplay -q %s; %s)&' % (
+            PrePlayCommand, shellArg(AudioFilename), PostPlayCommand) )
+    except Exception, e:
+        LOGGER.error('(ALARM) Failed to play audio file: %s' % e)
         return False
-    LOGGER.info('(ALARM) Start playing audio file...')
-    if Wait:
-        # loop until aplay quits
-        while os.popen('ps ax | grep -v grep | grep aplay').read() != '':
-            time.sleep(1)
-    LOGGER.info('(ALARM) Stopped playing audio file.')
+    LOGGER.info('(ALARM) Started playing audio file.')
     return True
 
 #############################################
@@ -1149,9 +1157,9 @@ def GetNetworks():
         
     return NetworkList
 
-def RemindNetwork():
+def RememberNetworkSettings():
     """
-    Save current active data network.
+    Save current active data network settings.
     """
     global ConnectionType
     global ConnectionIAP
@@ -1164,9 +1172,9 @@ def RemindNetwork():
 
     LOGGER.info( 'Saved current %s network (%s) for restore.' % (Type, ConnectionName) )
 
-def RestoreNetwork():
+def RestoreNetworkSettings():
     """
-    Re-enable previous stored data network.
+    Re-enable previous stored data network settings.
     """
     global ConnectionType
     global ConnectionName
@@ -1397,7 +1405,7 @@ def OnGPSstop(GpsControl, GpsData):
     global GpsIsTest
     if GpsIsTest:
         GpsIsTest = False
-        RestoreNetwork()
+        RestoreNetworkSettings()
         ExitDaemon()        
     
     LOGGER.info('Stopping GPS device.')
@@ -1638,7 +1646,7 @@ def DoCommandLine():
             Func = args.pop(0)
     
             if Func == 'gps1' or Func == 'gps2': 
-                RemindNetwork()
+                RememberNetworkSettings()
                 PrepareNetwork();
     
                 global GpsIsTest
@@ -1651,7 +1659,7 @@ def DoCommandLine():
                 return True
     
             if Func == 'ssh': # test mode for ssh connection
-                RemindNetwork()
+                RememberNetworkSettings()
                 PrepareNetwork();
                 DisableSSHcontrol(Verbose = False)
                 EnableSSHcontrol()
@@ -1662,10 +1670,10 @@ def DoCommandLine():
                 return True
 
             if Func == 'cam': # test mode for camera
-                RemindNetwork()
+                RememberNetworkSettings()
                 PrepareNetwork();
                 PerformCamera()
-                RestoreNetwork()
+                RestoreNetworkSettings()
                 SetAutoConnectBehaviour(ConnectionBehaviour)
 
             elif Func == 'sms': # test mode for sms
@@ -1675,7 +1683,7 @@ def DoCommandLine():
                 SMSsend(smscnf.SENDERNUMBER, ['Test SMS from Nokia N900 phone'], 'send SMS message test to {RECIPIENTNUMBER}')
 
             elif Func in ('email1', 'email2'): 
-                RemindNetwork()
+                RememberNetworkSettings()
                 PrepareNetwork();
 
                 if Func == 'email1': # test mode1 for email (text only)
@@ -1693,7 +1701,7 @@ def DoCommandLine():
                               Attachment =  ImageFilename,
                               Attachhint = 'image' )
 
-                RestoreNetwork()
+                RestoreNetworkSettings()
                 SetAutoConnectBehaviour(ConnectionBehaviour)
     
             elif Func == 'call': # test mode for phone call
@@ -2161,7 +2169,7 @@ def main():
  FIX: bug in GPSINTERVAL handeling; GPSINTERVAL was always set at 60 sec. regardless of user setting.
 
  0.7-2
- FIX: bug in RestoreNetwork(); (None must be 'NONE').
+ FIX: bug in RestoreNetworkSettings(); (None must be 'NONE').
  FIX: bug in heckArguments(); EnableScript() must be PerformShellScript().
  EXPERIMENTAL: updatechecker to save "smscon_config" file when updating to new version.
  
