@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 59 2011-12-21 01:52:57Z yablacky $
+# $Id: smsconlib.py 74 2011-12-23 01:10:39Z yablacky $
 ##############################################################
 
 # standard modules
@@ -21,7 +21,7 @@ def getSysBuildNameAndVersion(defaultName, defaultVersion = '999.1', headerInfo
     Analyze information from version control system to find out name and version of a branch.
     @param string defaultName Name to return if version information not recognized.
     @param string defaultVersion Version to return if version information not recognized.
-    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.4/src/opt/smscon/smsconlib.py 59 2011-12-21 01:52:57Z yablacky $ keyword to be analyzed.
+    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.5/src/opt/smscon/smsconlib.py 74 2011-12-23 01:10:39Z yablacky $ keyword to be analyzed.
     @param int dirLevel Number of extra dirs to walk up to find the one that contains version information (0 = parent dir).
     @return list (name, version) The name and version information.
     """
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.4/src/opt/smscon/smsconlib.py 59 2011-12-21 01:52:57Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.5/src/opt/smscon/smsconlib.py 74 2011-12-23 01:10:39Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -104,19 +104,58 @@ def DecodeAES(key, code):
 ##############################################################
 # Convenience functions. 
 
+def strReverse(s):
+    """
+    @param string s String to be reversed.
+    @return string string s in reverse character order.
+    """
+    return ''.join([s[-i] for i in range(1,1+len(s))])
+
+def commonPrefix(*args):
+    """@return string The longest same string that all passed strings are starting with"""
+    for idx in range(min(map(len, args))):
+        for s in args:
+            if s[idx] != args[0][idx]: 
+                return s[0:idx];
+    if len(args):   return args[0]
+    else:           return ''
+
+def shellArg(s):
+    """@return string The parameter s quoted to be safely used as a shell parameter."""
+    return "'%s'" % str(s).replace("\'", "'\"'\"'")
+
 def pidof(ProcessName):
     """
     Determine the PID of processes that match a given name.
     @return string Whitespace separator PID. Empty if none.
     """
-    PIDs = os.popen('pidof "%s"' % ProcessName).read().strip('\n')
+    PIDs = os.popen('pidof %s' % shellArg(ProcessName)).read().strip('\n')
     if PIDs != '':
         return PIDs
     PIDs = []
-    for psLine in os.popen('ps|grep -v grep|grep " %s"' % ProcessName).readlines():
+    for psLine in os.popen('ps|grep -v grep|grep %s' % shellArg(' ' + ProcessName)).readlines():
         PIDs.append(psLine.split()[0])
     return ' '.join(PIDs)
 
+def NormalizePhoneNumber(phoneNumber):
+    """
+    @param string phoneNumber A human written phone number like '+49 1234 55 666 - 92' or '(09876) 54321'
+    @return string normalized phone number; remove everything except digits and plus sign.
+    """ 
+    return re.sub('[^0-9+]', '', phoneNumber)
+
+def IsSamePhoneNumber(number1, number2):
+    """
+    @param string number1 A human written phone number to be compared.
+    @param string number2 A human written phone number to be compared.
+    @return bool True iff dialing either number will ring the same phone. 
+    """
+    norm1 = NormalizePhoneNumber(str(number1)).replace('+','0')
+    norm2 = NormalizePhoneNumber(str(number2)).replace('+','0')
+    while norm1[0:2] == '00': norm1 = norm1[1:]
+    while norm2[0:2] == '00': norm2 = norm2[1:]
+    return norm1 == norm2
+
 def IsHostReachable(hostname, pingCount = 3):
     """
     Check if remote host is available with a ping command and return
@@ -164,7 +203,8 @@ def SendSMSviaGSMmodem(RecipientNumber, Message, TryCountMax = 2):
     @return bool Success indicator
     """
     assert(len(Message) <= 160)
-    
+
+    RecipientNumber = NormalizePhoneNumber(RecipientNumber)
     DelaySeconds = 2
 
     modem = None
@@ -672,7 +712,7 @@ class UserConfiguration(Configuration):
     DefaultValueFormat  = '^\+?[X.@]+$' # '+XXXXXXXXXXX', 'XXXX@XXXXXXXX.XX', 'XXXX.XXXXXXXX.XX', ...
     _PhoneNumber        = '^\+?[0-9]+$'
     _CmdPattern         = ''
-    _BoolPattern        = '^yes|no$'
+    _BoolPattern        = '^(yes|no)$'
     _IntPattern         = '^\d+$'
     _FloatPattern       = '^\d+(\.\d+)?$'
     _EmailPattern       = '^[^@]+@[^@]+$'
